summaryrefslogtreecommitdiffstats
path: root/tdefilereplace
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2014-01-15 17:20:20 -0600
committerDarrell Anderson <humanreadable@yahoo.com>2014-01-15 17:20:20 -0600
commit80f849ebbb4bac48afd2bf50f0e8af2ffd9e4a65 (patch)
treed200f3206607ae1a50c7873a80ab5ffd325d6c2a /tdefilereplace
parentb23d738404d2fdf3445371a97fa267646b294394 (diff)
downloadtdewebdev-80f849ebbb4bac48afd2bf50f0e8af2ffd9e4a65.tar.gz
tdewebdev-80f849ebbb4bac48afd2bf50f0e8af2ffd9e4a65.zip
Finish renaming KFileReplace->TDEFileReplace and fix related Quanta Plus internal references.
Diffstat (limited to 'tdefilereplace')
-rw-r--r--tdefilereplace/ChangeLog4
-rw-r--r--tdefilereplace/main.cpp10
-rw-r--r--tdefilereplace/report.cpp2
-rw-r--r--tdefilereplace/tdefilereplace.cpp20
-rw-r--r--tdefilereplace/tdefilereplace.h10
-rw-r--r--tdefilereplace/tdefilereplaceiface.h2
-rw-r--r--tdefilereplace/tdefilereplacelib.cpp16
-rw-r--r--tdefilereplace/tdefilereplacelib.h2
-rw-r--r--tdefilereplace/tdefilereplacepart.cpp172
-rw-r--r--tdefilereplace/tdefilereplacepart.desktop4
-rw-r--r--tdefilereplace/tdefilereplacepart.h12
-rw-r--r--tdefilereplace/tdefilereplacepartui.rc2
-rw-r--r--tdefilereplace/tdefilereplaceview.cpp66
-rw-r--r--tdefilereplace/tdefilereplaceview.h4
-rw-r--r--tdefilereplace/tdefilereplaceviewwdg.ui4
-rw-r--r--tdefilereplace/whatthis.h4
16 files changed, 167 insertions, 167 deletions
diff --git a/tdefilereplace/ChangeLog b/tdefilereplace/ChangeLog
index 6f5d74f7..a9e751a7 100644
--- a/tdefilereplace/ChangeLog
+++ b/tdefilereplace/ChangeLog
@@ -77,7 +77,7 @@
code that do commands feature from KFileREplaceLib to these two classes.
2004-08-09 Emiliano Gulmini <emi_barbarossa@yahoo.it>
- * I fixed a bug that affected the method "void KFileReplaceView::slotStringsClear()" in tdefilereplaceview.cpp file.
+ * I fixed a bug that affected the method "void TDEFileReplaceView::slotStringsClear()" in tdefilereplaceview.cpp file.
This bug caused the list of strings not to be correctly erased.
2004-08-07 Emiliano Gulmini <emi_barbarossa@yahoo.it>
@@ -172,7 +172,7 @@
* Fixed a bug in the new kfr (XML-based) file format.
2004-03-12 Emiliano Gulmini <emi_barbarossa@yahoo.it>
- * Removed KresultView(.h,.cpp). Now KFileReplaceView is a QWidget that contains results and
+ * Removed KresultView(.h,.cpp). Now TDEFileReplaceView is a QWidget that contains results and
strings view.
* Added whatthis.h that contains the "what's this" strings.
* Fixed a bug that generate a wrong XHTML result file.
diff --git a/tdefilereplace/main.cpp b/tdefilereplace/main.cpp
index da78eb23..1ca0ce24 100644
--- a/tdefilereplace/main.cpp
+++ b/tdefilereplace/main.cpp
@@ -1,5 +1,5 @@
/***************************************************************************
- main.cpp - Main file for the KFileReplace shell
+ main.cpp - Main file for the TDEFileReplace shell
-------------------
begin : Thu Sep 16 14:14:09 2004
copyright : (C) 2004 by Andras Mantia <amantia@kde.org>
@@ -34,14 +34,14 @@ static TDECmdLineOptions options[] =
int main(int argc, char *argv[])
{
- TDEAboutData about("tdefilereplace", I18N_NOOP("KFileReplace"), version, description,
+ TDEAboutData about("tdefilereplace", I18N_NOOP("TDEFileReplace"), version, description,
TDEAboutData::License_GPL_V2, "(C) 2004-2005 Andras Mantia\n(C) 2004-2005 Emiliano Gulmini\n(C) 1999-2002 Francois Dupoux", I18N_NOOP("Part of the KDEWebDev module."),
"http://www.kdewebdev.org");
about.addAuthor("Andras Mantia", I18N_NOOP("Shell author, KPart creator, co-maintainer"), "amantia@kde.org");
about.addAuthor("Emiliano Gulmini", I18N_NOOP("Current maintainer, code cleaner and rewriter"),"emi_barbarossa@yahoo.it");
about.addAuthor("Francois Dupou",
- I18N_NOOP("Original author of the KFileReplace tool"),
+ I18N_NOOP("Original author of the TDEFileReplace tool"),
"dupoux@dupoux.com");
TDECmdLineArgs::init(argc, argv, &about);
@@ -52,14 +52,14 @@ int main(int argc, char *argv[])
// see if we are starting with session management
if (app.isRestored())
{
- RESTORE(KFileReplace);
+ RESTORE(TDEFileReplace);
}
else
{
// no session.. just start up normally
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
- KFileReplace *kfr = new KFileReplace;
+ TDEFileReplace *kfr = new TDEFileReplace;
kfr->show();
if (args->count() == 0)
diff --git a/tdefilereplace/report.cpp b/tdefilereplace/report.cpp
index a3b7dfab..3be703e2 100644
--- a/tdefilereplace/report.cpp
+++ b/tdefilereplace/report.cpp
@@ -65,7 +65,7 @@ void Report::createReportFile()
oTStream << "<?xml version=\"1.0\"?>\n"
"<?xml-stylesheet href=\""+css+"\" type=\"text/css\"?>"
"<report>\n"
- " <title> "+i18n("KFileReplace Report")+" </title>\n"
+ " <title> "+i18n("TDEFileReplace Report")+" </title>\n"
" <createdby>"+user.fullName()+"("+user.loginName()+")"+"</createdby>\n"
" <date>"+dateString+"</date>\n"
"<hr/>\n"
diff --git a/tdefilereplace/tdefilereplace.cpp b/tdefilereplace/tdefilereplace.cpp
index 24ead465..8cb7d332 100644
--- a/tdefilereplace/tdefilereplace.cpp
+++ b/tdefilereplace/tdefilereplace.cpp
@@ -1,5 +1,5 @@
/***************************************************************************
- tdefilereplace.cpp - KFileReplace shell implementation
+ tdefilereplace.cpp - TDEFileReplace shell implementation
-------------------
begin : Thu Sep 16 14:14:09 2004
copyright : (C) 2004 by Andras Mantia <amantia@kde.org>
@@ -24,8 +24,8 @@
//app includes
#include "tdefilereplace.h"
-KFileReplace::KFileReplace()
- : KParts::MainWindow(0L, "KFileReplace")
+TDEFileReplace::TDEFileReplace()
+ : KParts::MainWindow(0L, "TDEFileReplace")
{
KLibFactory *factory = KLibLoader::self()->factory("libtdefilereplacepart");
if (factory)
@@ -46,23 +46,23 @@ KFileReplace::KFileReplace()
}
else
{
- KMessageBox::error(this, i18n("Could not find the KFileReplace part."));
+ KMessageBox::error(this, i18n("Could not find the TDEFileReplace part."));
close();
return;
}
}
-KFileReplace::~KFileReplace()
+TDEFileReplace::~TDEFileReplace()
{
}
-void KFileReplace::openURL(const KURL &url)
+void TDEFileReplace::openURL(const KURL &url)
{
m_part->openURL(url);
}
-void KFileReplace::slotConfigureKeys()
+void TDEFileReplace::slotConfigureKeys()
{
KKeyDialog dlg( false, this );
TQPtrList<KXMLGUIClient> clients = guiFactory()->clients();
@@ -74,7 +74,7 @@ void KFileReplace::slotConfigureKeys()
dlg.configure();
}
-void KFileReplace::slotConfigureToolbars()
+void TDEFileReplace::slotConfigureToolbars()
{
saveMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
KEditToolbar dlg(factory());
@@ -83,13 +83,13 @@ void KFileReplace::slotConfigureToolbars()
dlg.exec();
}
-void KFileReplace::applyNewToolbarConfig()
+void TDEFileReplace::applyNewToolbarConfig()
{
applyMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
}
-void KFileReplace::removeDuplicatedActions()
+void TDEFileReplace::removeDuplicatedActions()
{
TDEActionCollection* part_action_collection = m_part->actionCollection();
TDEAction* part_about_action = part_action_collection->action("help_about_tdefilereplace");
diff --git a/tdefilereplace/tdefilereplace.h b/tdefilereplace/tdefilereplace.h
index 7da206fd..2742a5c7 100644
--- a/tdefilereplace/tdefilereplace.h
+++ b/tdefilereplace/tdefilereplace.h
@@ -1,5 +1,5 @@
/***************************************************************************
- tdefilereplace.h - KFileReplace header
+ tdefilereplace.h - TDEFileReplace header
-------------------
begin : Thu Sep 16 14:14:09 2004
copyright : (C) 2004 by Andras Mantia <amantia@kde.org>
@@ -19,17 +19,17 @@
#include <tdeparts/mainwindow.h>
/**
-Shell application for the KFileReplace part.
+Shell application for the TDEFileReplace part.
@author Andras Mantia
*/
-class KFileReplace : public KParts::MainWindow
+class TDEFileReplace : public KParts::MainWindow
{
Q_OBJECT
public:
- KFileReplace();
- ~KFileReplace();
+ TDEFileReplace();
+ ~TDEFileReplace();
void openURL(const KURL &url);
private slots:
diff --git a/tdefilereplace/tdefilereplaceiface.h b/tdefilereplace/tdefilereplaceiface.h
index 77be035f..2d87e08a 100644
--- a/tdefilereplace/tdefilereplaceiface.h
+++ b/tdefilereplace/tdefilereplaceiface.h
@@ -19,7 +19,7 @@
#include <dcopobject.h>
-class KFileReplaceIface : virtual public DCOPObject
+class TDEFileReplaceIface : virtual public DCOPObject
{
K_DCOP
diff --git a/tdefilereplace/tdefilereplacelib.h b/tdefilereplace/tdefilereplacelib.h
index 74d26ee4..d04f8a34 100644
--- a/tdefilereplace/tdefilereplacelib.h
+++ b/tdefilereplace/tdefilereplacelib.h
@@ -28,7 +28,7 @@ class KlistView;
// local
#include "configurationclasses.h"
-class KFileReplaceLib
+class TDEFileReplaceLib
{
public:
diff --git a/tdefilereplace/tdefilereplacepart.cpp b/tdefilereplace/tdefilereplacepart.cpp
index ffbc029d..e196a15c 100644
--- a/tdefilereplace/tdefilereplacepart.cpp
+++ b/tdefilereplace/tdefilereplacepart.cpp
@@ -56,11 +56,11 @@ using namespace whatthisNameSpace;
//PUBLIC CONSTRUCTORS
// Factory code for KDE 3
-typedef KParts::GenericFactory<KFileReplacePart> FileReplaceFactory;
+typedef KParts::GenericFactory<TDEFileReplacePart> FileReplaceFactory;
K_EXPORT_COMPONENT_FACTORY( libtdefilereplacepart, FileReplaceFactory )
-KFileReplacePart::KFileReplacePart(TQWidget* parentWidget, const char* , TQObject* parent, const char* name, const TQStringList & ) : KParts::ReadOnlyPart(parent,name)
+TDEFileReplacePart::TDEFileReplacePart(TQWidget* parentWidget, const char* , TQObject* parent, const char* name, const TQStringList & ) : KParts::ReadOnlyPart(parent,name)
{
setInstance(FileReplaceFactory::instance());
TDEGlobal::locale()->insertCatalogue("tdefilereplace");
@@ -79,7 +79,7 @@ KFileReplacePart::KFileReplacePart(TQWidget* parentWidget, const char* , TQObjec
whatsThis();
}
-KFileReplacePart::~KFileReplacePart()
+TDEFileReplacePart::~TDEFileReplacePart()
{
m_view = 0; //it's already deleted, so set it to NULL
@@ -95,14 +95,14 @@ KFileReplacePart::~KFileReplacePart()
}
//PRIVATE SLOTS
-void KFileReplacePart::slotSetNewParameters()
+void TDEFileReplacePart::slotSetNewParameters()
{
launchNewProjectDialog(KURL());
m_view->changeView(m_option->m_searchingOnlyMode);
emit setStatusBarText(i18n("Ready."));
}
-void KFileReplacePart::slotSearchingOperation()
+void TDEFileReplacePart::slotSearchingOperation()
{
if(!checkBeforeOperation())
return;
@@ -159,7 +159,7 @@ void KFileReplacePart::slotSearchingOperation()
m_view->showSemaphore("green");
}
-void KFileReplacePart::slotReplacingOperation()
+void TDEFileReplacePart::slotReplacingOperation()
{
if (KMessageBox::warningContinueCancel(m_w, i18n("<qt>You have selected <b>%1</b> as the encoding of the files.<br>Selecting the correct encoding is very important as if you have files that have some other encoding than the selected one, after a replace you may damage those files.<br><br>In case you do not know the encoding of your files, select <i>utf8</i> and <b>enable</b> the creation of backup files. This setting will autodetect <i>utf8</i> and <i>utf16</i> files, but the changed files will be converted to <i>utf8</i>.</qt>").arg(m_option->m_encoding), i18n("File Encoding Warning"), KStdGuiItem::cont(), "ShowEncodingWarning") == KMessageBox::Cancel)
return;
@@ -221,14 +221,14 @@ void KFileReplacePart::slotReplacingOperation()
m_view->showSemaphore("green");
}
-void KFileReplacePart::slotSimulatingOperation()
+void TDEFileReplacePart::slotSimulatingOperation()
{
m_option->m_simulation = true;
slotReplacingOperation();
m_option->m_simulation = false;
}
-void KFileReplacePart::slotStop()
+void TDEFileReplacePart::slotStop()
{
emit setStatusBarText(i18n("Stopping..."));
m_stop = true;
@@ -236,7 +236,7 @@ void KFileReplacePart::slotStop()
resetActions();
}
-void KFileReplacePart::slotCreateReport()
+void TDEFileReplacePart::slotCreateReport()
{
// Check there are results
TDEListView* rv = m_view->getResultsView(),
@@ -280,13 +280,13 @@ void KFileReplacePart::slotCreateReport()
//resetActions();
}
-void KFileReplacePart::slotStringsAdd()
+void TDEFileReplacePart::slotStringsAdd()
{
m_view->slotStringsAdd();
resetActions();
}
-void KFileReplacePart::slotQuickStringsAdd()
+void TDEFileReplacePart::slotQuickStringsAdd()
{
//this slot handles a pair of strings that come from project dialog,
//if the control character 'N' is found at the position 0 of the two strings,
@@ -318,33 +318,33 @@ void KFileReplacePart::slotQuickStringsAdd()
slotReplacingOperation();
}
-void KFileReplacePart::slotStringsDeleteItem()
+void TDEFileReplacePart::slotStringsDeleteItem()
{
m_view->slotStringsDeleteItem();
resetActions();
}
-void KFileReplacePart::slotStringsEmpty()
+void TDEFileReplacePart::slotStringsEmpty()
{
m_view->slotStringsEmpty();
resetActions();
}
-void KFileReplacePart::slotStringsEdit()
+void TDEFileReplacePart::slotStringsEdit()
{
m_view->slotStringsEdit();
resetActions();
}
-void KFileReplacePart::slotStringsSave()
+void TDEFileReplacePart::slotStringsSave()
{
m_view->slotStringsSave();
}
-void KFileReplacePart::slotStringsLoad()
+void TDEFileReplacePart::slotStringsLoad()
{
// Selects the file to load from
- TQString menu = "*.kfr|" + i18n("KFileReplace strings") + " (*.kfr)\n*|"+i18n("All Files") + " (*)";
+ TQString menu = "*.kfr|" + i18n("TDEFileReplace strings") + " (*.kfr)\n*|"+i18n("All Files") + " (*)";
TQString fileName = KFileDialog::getOpenFileName(TQString(), menu, m_w, i18n("Load Strings From File"));
if(!fileName.isEmpty())
@@ -353,19 +353,19 @@ void KFileReplacePart::slotStringsLoad()
resetActions();
}
-void KFileReplacePart::slotStringsInvertCur()
+void TDEFileReplacePart::slotStringsInvertCur()
{
m_view->stringsInvert(false);
resetActions();
}
-void KFileReplacePart::slotStringsInvertAll()
+void TDEFileReplacePart::slotStringsInvertAll()
{
m_view->stringsInvert(true);
resetActions();
}
-void KFileReplacePart::slotOpenRecentStringFile(const KURL& urlFile)
+void TDEFileReplacePart::slotOpenRecentStringFile(const KURL& urlFile)
{
TQString fileName;
@@ -386,37 +386,37 @@ void KFileReplacePart::slotOpenRecentStringFile(const KURL& urlFile)
resetActions();
}
-void KFileReplacePart::slotOptionRecursive()
+void TDEFileReplacePart::slotOptionRecursive()
{
m_option->m_recursive = !m_option->m_recursive;
resetActions();
}
-void KFileReplacePart::slotOptionBackup()
+void TDEFileReplacePart::slotOptionBackup()
{
m_option->m_backup = !m_option->m_backup;
resetActions();
}
-void KFileReplacePart::slotOptionCaseSensitive()
+void TDEFileReplacePart::slotOptionCaseSensitive()
{
m_option->m_caseSensitive = !m_option->m_caseSensitive;
resetActions();
}
-void KFileReplacePart::slotOptionVariables()
+void TDEFileReplacePart::slotOptionVariables()
{
m_option->m_variables = !m_option->m_variables;
resetActions();
}
-void KFileReplacePart::slotOptionRegularExpressions()
+void TDEFileReplacePart::slotOptionRegularExpressions()
{
m_option->m_regularExpressions = !m_option->m_regularExpressions;
resetActions();
}
-void KFileReplacePart::slotOptionPreferences()
+void TDEFileReplacePart::slotOptionPreferences()
{
KOptionsDlg dlg(m_option, m_w, 0);
@@ -429,7 +429,7 @@ void KFileReplacePart::slotOptionPreferences()
resetActions();
}
-void KFileReplacePart::showAboutApplication()
+void TDEFileReplacePart::showAboutApplication()
{
m_aboutDlg = new TDEAboutApplication(createAboutData(), (TQWidget *)0, (const char *)0, false);
if(m_aboutDlg == 0)
@@ -441,18 +441,18 @@ void KFileReplacePart::showAboutApplication()
m_aboutDlg->raise();
}
-void KFileReplacePart::appHelpActivated()
+void TDEFileReplacePart::appHelpActivated()
{
kapp->invokeHelp(TQString(), "tdefilereplace");
}
-void KFileReplacePart::reportBug()
+void TDEFileReplacePart::reportBug()
{
KBugReport dlg(m_w, true, createAboutData());
dlg.exec();
}
-void KFileReplacePart::resetActions()
+void TDEFileReplacePart::resetActions()
{
TDEListView* rv = m_view->getResultsView(),
* sv = m_view->getStringsView();
@@ -507,16 +507,16 @@ void KFileReplacePart::resetActions()
}
//PUBLIC METHODS
-TDEAboutData* KFileReplacePart::createAboutData()
+TDEAboutData* TDEFileReplacePart::createAboutData()
{
TDEAboutData * aboutData = new TDEAboutData("tdefilereplacepart",
- I18N_NOOP("KFileReplacePart"),
+ I18N_NOOP("TDEFileReplacePart"),
KFR_VERSION,
I18N_NOOP( "Batch search and replace tool."),
TDEAboutData::License_GPL_V2,
"(C) 1999-2002 Fran�is Dupoux\n(C) 2003-2004 Andras Mantia\n(C) 2004 Emiliano Gulmini", I18N_NOOP("Part of the KDEWebDev module."), "http://www.kdewebdev.org");
aboutData->addAuthor("Fran�is Dupoux",
- I18N_NOOP("Original author of the KFileReplace tool"),
+ I18N_NOOP("Original author of the TDEFileReplace tool"),
"dupoux@dupoux.com");
aboutData->addAuthor("Emiliano Gulmini",
I18N_NOOP("Current maintainer, code cleaner and rewriter"),
@@ -531,11 +531,11 @@ TDEAboutData* KFileReplacePart::createAboutData()
}
//PROTECTED METHODS
-bool KFileReplacePart::openURL(const KURL &url)
+bool TDEFileReplacePart::openURL(const KURL &url)
{
if(!url.isEmpty() && (url.protocol() != "file"))
{
- KMessageBox::sorry(m_w, i18n("Sorry, currently the KFileReplace part works only for local files."), i18n("Non Local File"));
+ KMessageBox::sorry(m_w, i18n("Sorry, currently the TDEFileReplace part works only for local files."), i18n("Non Local File"));
emit canceled("");
return false;
}
@@ -549,7 +549,7 @@ bool KFileReplacePart::openURL(const KURL &url)
}
//PRIVATE METHODS
-void KFileReplacePart::initGUI()
+void TDEFileReplacePart::initGUI()
{
setXMLFile("tdefilereplacepartui.rc");
@@ -592,7 +592,7 @@ void KFileReplacePart::initGUI()
(void)new TDEToggleAction(i18n("Case &Sensitive"), "casesensitive_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionCaseSensitive()), actionCollection(), "options_case");
(void)new TDEToggleAction(i18n("Enable Commands &in Replace String: [$command:option$]"), "command_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionVariables()), actionCollection(), "options_var");
(void)new TDEToggleAction(i18n("Enable &Regular Expressions"), "regularexpression_option", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionRegularExpressions()), actionCollection(), "options_regularexpressions");
- (void)new TDEAction(i18n("Configure &KFileReplace..."), "configure", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionPreferences()), actionCollection(), "configure_tdefilereplace");
+ (void)new TDEAction(i18n("Configure &TDEFileReplace..."), "configure", 0, TQT_TQOBJECT(this), TQT_SLOT(slotOptionPreferences()), actionCollection(), "configure_tdefilereplace");
// Results
(void)new TDEAction(i18n("&Properties"), "informations", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultProperties()), actionCollection(), "results_infos");
@@ -606,15 +606,15 @@ void KFileReplacePart::initGUI()
(void)new TDEAction(i18n("&Delete"), "editdelete", 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultDelete()), actionCollection(), "results_delete");
(void)new TDEAction(i18n("E&xpand Tree"), 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultTreeExpand()), actionCollection(), "results_treeexpand");
(void)new TDEAction(i18n("&Reduce Tree"), 0, TQT_TQOBJECT(m_view), TQT_SLOT(slotResultTreeReduce()), actionCollection(), "results_treereduce");
- (void)new TDEAction(i18n("&About KFileReplace"), "tdefilereplace", 0, TQT_TQOBJECT(this), TQT_SLOT(showAboutApplication()), actionCollection(), "help_about_tdefilereplace");
- (void)new TDEAction(i18n("KFileReplace &Handbook"), "help", 0, TQT_TQOBJECT(this), TQT_SLOT(appHelpActivated()), actionCollection(), "help_tdefilereplace");
+ (void)new TDEAction(i18n("&About TDEFileReplace"), "tdefilereplace", 0, TQT_TQOBJECT(this), TQT_SLOT(showAboutApplication()), actionCollection(), "help_about_tdefilereplace");
+ (void)new TDEAction(i18n("TDEFileReplace &Handbook"), "help", 0, TQT_TQOBJECT(this), TQT_SLOT(appHelpActivated()), actionCollection(), "help_tdefilereplace");
(void)new TDEAction(i18n("&Report Bug"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(reportBug()), actionCollection(), "report_bug");
}
-void KFileReplacePart::initView()
+void TDEFileReplacePart::initView()
{
- m_view = new KFileReplaceView(m_option, m_parentWidget, "view");
+ m_view = new TDEFileReplaceView(m_option, m_parentWidget, "view");
setWidget(m_view);
@@ -623,7 +623,7 @@ void KFileReplacePart::initView()
m_view->showSemaphore("green");
}
-void KFileReplacePart::freezeActions()
+void TDEFileReplacePart::freezeActions()
{
//Disables actions during search/replace operation
actionCollection()->action("new_project")->setEnabled(false);
@@ -661,7 +661,7 @@ void KFileReplacePart::freezeActions()
((TDEToggleAction* ) actionCollection()->action("options_regularexpressions"))->setChecked(false);
}
-void KFileReplacePart::loadOptionsFromRC()
+void TDEFileReplacePart::loadOptionsFromRC()
{
m_option = new RCOptions();
@@ -674,7 +674,7 @@ void KFileReplacePart::loadOptionsFromRC()
loadBackupExtensionOptions();
}
-void KFileReplacePart::loadOptions()
+void TDEFileReplacePart::loadOptions()
{
m_config->setGroup("General Options");
@@ -709,7 +709,7 @@ void KFileReplacePart::loadOptions()
m_option->m_askConfirmReplace = false;
}
-void KFileReplacePart::loadFileSizeOptions()
+void TDEFileReplacePart::loadFileSizeOptions()
{
m_config->setGroup("Size options");
@@ -717,7 +717,7 @@ void KFileReplacePart::loadFileSizeOptions()
m_option->m_maxSize = m_config->readNumEntry(rcMaxFileSize, FileSizeOption);
}
-void KFileReplacePart::loadDateAccessOptions()
+void TDEFileReplacePart::loadDateAccessOptions()
{
m_config->setGroup("Access options");
@@ -726,7 +726,7 @@ void KFileReplacePart::loadDateAccessOptions()
m_option->m_maxDate = m_config->readEntry(rcMaxDate, AccessDateOption);
}
-void KFileReplacePart::loadOwnerOptions()
+void TDEFileReplacePart::loadOwnerOptions()
{
m_config->setGroup("Owner options");
@@ -752,7 +752,7 @@ void KFileReplacePart::loadOwnerOptions()
m_option->m_ownerGroupValue = ownerList[3];
}
-void KFileReplacePart::loadLocationsList()
+void TDEFileReplacePart::loadLocationsList()
{
m_config->setGroup("Directories");
TQStringList locationsEntryList;
@@ -768,7 +768,7 @@ void KFileReplacePart::loadLocationsList()
m_option->m_directories = locationsEntryList;
}
-void KFileReplacePart::loadFiltersList()
+void TDEFileReplacePart::loadFiltersList()
{
TQStringList filtersEntryList;
@@ -785,7 +785,7 @@ void KFileReplacePart::loadFiltersList()
m_option->m_filters = filtersEntryList;
}
-void KFileReplacePart::loadBackupExtensionOptions()
+void TDEFileReplacePart::loadBackupExtensionOptions()
{
m_config->setGroup("Options");
TQStringList bkList = TQStringList::split(',',
@@ -799,7 +799,7 @@ void KFileReplacePart::loadBackupExtensionOptions()
m_option->m_backupExtension = bkList[1];
}
-void KFileReplacePart::saveOptionsToRC()
+void TDEFileReplacePart::saveOptionsToRC()
{
saveOptions();
saveFileSizeOptions();
@@ -810,7 +810,7 @@ void KFileReplacePart::saveOptionsToRC()
saveBackupExtensionOptions();
}
-void KFileReplacePart::saveOptions()
+void TDEFileReplacePart::saveOptions()
{
m_config->setGroup("General Options");
@@ -841,7 +841,7 @@ void KFileReplacePart::saveOptions()
m_config->sync();
}
-void KFileReplacePart::saveFileSizeOptions()
+void TDEFileReplacePart::saveFileSizeOptions()
{
m_config->setGroup("Size options");
@@ -851,7 +851,7 @@ void KFileReplacePart::saveFileSizeOptions()
m_config->sync();
}
-void KFileReplacePart::saveDateAccessOptions()
+void TDEFileReplacePart::saveDateAccessOptions()
{
m_config->setGroup("Access options");
@@ -862,7 +862,7 @@ void KFileReplacePart::saveDateAccessOptions()
m_config->sync();
}
-void KFileReplacePart::saveOwnerOptions()
+void TDEFileReplacePart::saveOwnerOptions()
{
m_config->setGroup("Owner options");
@@ -895,7 +895,7 @@ void KFileReplacePart::saveOwnerOptions()
m_config->sync();
}
-void KFileReplacePart::saveLocationsList()
+void TDEFileReplacePart::saveLocationsList()
{
m_config->setGroup("Directories");
#if KDE_IS_VERSION(3,1,3)
@@ -906,14 +906,14 @@ void KFileReplacePart::saveLocationsList()
m_config->sync();
}
-void KFileReplacePart::saveFiltersList()
+void TDEFileReplacePart::saveFiltersList()
{
m_config->setGroup("Filters");
m_config->writeEntry(rcFiltersList, m_option->m_filters);
m_config->sync();
}
-void KFileReplacePart::saveBackupExtensionOptions()
+void TDEFileReplacePart::saveBackupExtensionOptions()
{
m_config->setGroup("Options");
TQString bkOptions;
@@ -926,7 +926,7 @@ void KFileReplacePart::saveBackupExtensionOptions()
m_config->sync();
}
-void KFileReplacePart::fileReplace()
+void TDEFileReplacePart::fileReplace()
{
TQString directoryName = m_option->m_directories[0];
TQDir d(directoryName);
@@ -949,7 +949,7 @@ void KFileReplacePart::fileReplace()
break;
// Avoids files that not match requirements
- if(!KFileReplaceLib::isAnAccessibleFile(d.canonicalPath(), fileName, m_option))
+ if(!TDEFileReplaceLib::isAnAccessibleFile(d.canonicalPath(), fileName, m_option))
continue;
kapp->processEvents();
if(m_option->m_backup)
@@ -962,7 +962,7 @@ void KFileReplacePart::fileReplace()
}
}
-void KFileReplacePart::recursiveFileReplace(const TQString& directoryName, int& filesNumber)
+void TDEFileReplacePart::recursiveFileReplace(const TQString& directoryName, int& filesNumber)
{
//if m_stop == true then interrupts recursion
if(m_stop)
@@ -987,7 +987,7 @@ void KFileReplacePart::recursiveFileReplace(const TQString& directoryName, int&
TQString fileName = (*filesIt);
// Avoids files that not match requirements
- if(!KFileReplaceLib::isAnAccessibleFile(d.canonicalPath(),fileName, m_option))
+ if(!TDEFileReplaceLib::isAnAccessibleFile(d.canonicalPath(),fileName, m_option))
continue;
TQString filePath = d.canonicalPath()+"/"+fileName;
@@ -1014,7 +1014,7 @@ void KFileReplacePart::recursiveFileReplace(const TQString& directoryName, int&
}
}
-void KFileReplacePart::replaceAndBackup(const TQString& currentDir, const TQString& oldFileName)
+void TDEFileReplacePart::replaceAndBackup(const TQString& currentDir, const TQString& oldFileName)
{
//Creates a path string
TQString oldPathString = currentDir+"/"+oldFileName;
@@ -1033,7 +1033,7 @@ void KFileReplacePart::replaceAndBackup(const TQString& currentDir, const TQStri
TQString line = currentStream.read(),
backupLine = line;
- TQString backupSize = KFileReplaceLib::formatFileSize(currentFile.size());
+ TQString backupSize = TDEFileReplaceLib::formatFileSize(currentFile.size());
currentFile.close();
@@ -1081,10 +1081,10 @@ void KFileReplacePart::replaceAndBackup(const TQString& currentDir, const TQStri
if(atLeastOneStringFound && item/* && atLeastOneStringConfirmed*/)
{
- KFileReplaceLib::setIconForFileEntry(item,currentDir+"/"+oldFileName);
+ TDEFileReplaceLib::setIconForFileEntry(item,currentDir+"/"+oldFileName);
item->setText(0,oldFileName);
item->setText(1,currentDir);
- TQString newSize = KFileReplaceLib::formatFileSize(oldFileInfo.size());
+ TQString newSize = TDEFileReplaceLib::formatFileSize(oldFileInfo.size());
if(!m_option->m_simulation)
{
item->setText(2, backupSize);
@@ -1102,7 +1102,7 @@ void KFileReplacePart::replaceAndBackup(const TQString& currentDir, const TQStri
}
}
-void KFileReplacePart::replaceAndOverwrite(const TQString& currentDir, const TQString& oldFileName)
+void TDEFileReplacePart::replaceAndOverwrite(const TQString& currentDir, const TQString& oldFileName)
{
TQString oldPathString = currentDir+"/"+oldFileName;
TQFile oldFile(oldPathString);
@@ -1114,7 +1114,7 @@ void KFileReplacePart::replaceAndOverwrite(const TQString& currentDir, const TQS
return ;
}
- TQString fileSizeBeforeReplacing = KFileReplaceLib::formatFileSize(oldFileInfo.size());
+ TQString fileSizeBeforeReplacing = TDEFileReplaceLib::formatFileSize(oldFileInfo.size());
TDEListViewItem *item = 0;
TQTextStream oldStream( &oldFile );
@@ -1153,7 +1153,7 @@ void KFileReplacePart::replaceAndOverwrite(const TQString& currentDir, const TQS
}
TQFileInfo nf(oldPathString);
- TQString fileSizeAfterReplacing = KFileReplaceLib::formatFileSize(nf.size());
+ TQString fileSizeAfterReplacing = TDEFileReplaceLib::formatFileSize(nf.size());
//if ignoreFiles == false then every files must be show
if(!m_option->m_ignoreFiles)
@@ -1161,7 +1161,7 @@ void KFileReplacePart::replaceAndOverwrite(const TQString& currentDir, const TQS
if(atLeastOneStringFound && item/*&& atLeastOneStringConfirmed*/)
{
- KFileReplaceLib::setIconForFileEntry(item,currentDir+"/"+oldFileName);
+ TDEFileReplaceLib::setIconForFileEntry(item,currentDir+"/"+oldFileName);
item->setText(0,oldFileName);
item->setText(1,currentDir);
item->setText(2,fileSizeBeforeReplacing);
@@ -1176,7 +1176,7 @@ void KFileReplacePart::replaceAndOverwrite(const TQString& currentDir, const TQS
}
}
-void KFileReplacePart::replacingLoop(TQString& line, TDEListViewItem** item, bool& atLeastOneStringFound, int& occur, bool regularExpression, bool& askConfirmReplace)
+void TDEFileReplacePart::replacingLoop(TQString& line, TDEListViewItem** item, bool& atLeastOneStringFound, int& occur, bool regularExpression, bool& askConfirmReplace)
{
KeyValueMap tempMap = m_replacementMap;
KeyValueMap::Iterator it;
@@ -1244,7 +1244,7 @@ void KFileReplacePart::replacingLoop(TQString& line, TDEListViewItem** item, boo
}
}
-void KFileReplacePart::fileSearch(const TQString& directoryName, const TQString& filters)
+void TDEFileReplacePart::fileSearch(const TQString& directoryName, const TQString& filters)
{
TQDir d(directoryName);
@@ -1267,7 +1267,7 @@ void KFileReplacePart::fileSearch(const TQString& directoryName, const TQString&
TQString fileName = (*filesIt);
// Avoids files that not match
- if(!KFileReplaceLib::isAnAccessibleFile(filePath, fileName, m_option))
+ if(!TDEFileReplaceLib::isAnAccessibleFile(filePath, fileName, m_option))
continue;
TQFileInfo fileInfo(filePath+"/"+fileName);
@@ -1280,7 +1280,7 @@ void KFileReplacePart::fileSearch(const TQString& directoryName, const TQString&
}
}
-void KFileReplacePart::recursiveFileSearch(const TQString& directoryName, const TQString& filters, uint& filesNumber)
+void TDEFileReplacePart::recursiveFileSearch(const TQString& directoryName, const TQString& filters, uint& filesNumber)
{
// if m_stop == true then interrupt recursion
if(m_stop)
@@ -1304,7 +1304,7 @@ void KFileReplacePart::recursiveFileSearch(const TQString& directoryName, const
TQString fileName = (*filesIt);
// Avoids files that not match
- if(!KFileReplaceLib::isAnAccessibleFile(filePath, fileName, m_option))
+ if(!TDEFileReplaceLib::isAnAccessibleFile(filePath, fileName, m_option))
continue;
// Composes file path string
@@ -1326,7 +1326,7 @@ void KFileReplacePart::recursiveFileSearch(const TQString& directoryName, const
}
}
-void KFileReplacePart::search(const TQString& currentDir, const TQString& fileName)
+void TDEFileReplacePart::search(const TQString& currentDir, const TQString& fileName)
{
TQFile file(currentDir+"/"+fileName);
@@ -1470,17 +1470,17 @@ void KFileReplacePart::search(const TQString& currentDir, const TQString& fileNa
if(atLeastOneStringFound && item)
{
- KFileReplaceLib::setIconForFileEntry(item,currentDir+"/"+fileName);
+ TDEFileReplaceLib::setIconForFileEntry(item,currentDir+"/"+fileName);
item->setText(0,fileName);
item->setText(1,currentDir);
- item->setText(2,KFileReplaceLib::formatFileSize(fileInfo.size()));
+ item->setText(2,TDEFileReplaceLib::formatFileSize(fileInfo.size()));
item->setText(3,TQString::number(occurrence,10));
item->setText(4,TQString("%1[%2]").arg(fileInfo.owner()).arg(fileInfo.ownerId()));
item->setText(5,TQString("%1[%2]").arg(fileInfo.group()).arg(fileInfo.groupId()));
}
}
-void KFileReplacePart::loadViewContent()
+void TDEFileReplacePart::loadViewContent()
{
/* Maps the content of the strings view to a TQMap */
KeyValueMap tempMap;
@@ -1499,7 +1499,7 @@ void KFileReplacePart::loadViewContent()
m_replacementMap = tempMap;
}
-void KFileReplacePart::loadRulesFile(const TQString& fileName)
+void TDEFileReplacePart::loadRulesFile(const TQString& fileName)
{
/* Loads a file with kfr extension.
* creates a xml document and browses it*/
@@ -1519,7 +1519,7 @@ void KFileReplacePart::loadRulesFile(const TQString& fileName)
KMessageBox::information(m_w, i18n("<qt>File <b>%1</b> seems not to be written in new kfr format. Remember that the old kfr format will be soon abandoned. You can convert your old rules files by simply saving them with tdefilereplace.</qt>").arg(fileName),i18n("Warning"));
- KFileReplaceLib::convertOldToNewKFRFormat(fileName, sv);
+ TDEFileReplaceLib::convertOldToNewKFRFormat(fileName, sv);
return;
}
@@ -1583,7 +1583,7 @@ void KFileReplacePart::loadRulesFile(const TQString& fileName)
//resetActions();
}
-bool KFileReplacePart::launchNewProjectDialog(const KURL & startURL)
+bool TDEFileReplacePart::launchNewProjectDialog(const KURL & startURL)
{
if(!startURL.isEmpty())
m_option->m_directories.prepend(startURL.path());
@@ -1607,7 +1607,7 @@ bool KFileReplacePart::launchNewProjectDialog(const KURL & startURL)
return true;
}
-void KFileReplacePart::setOptionMask()
+void TDEFileReplacePart::setOptionMask()
{
m_optionMask |= TQDir::Dirs;
@@ -1618,7 +1618,7 @@ void KFileReplacePart::setOptionMask()
m_optionMask |= TQDir::NoSymLinks;
}
-bool KFileReplacePart::checkBeforeOperation()
+bool TDEFileReplacePart::checkBeforeOperation()
{
loadViewContent();
TDEListView* sv = m_view->getStringsView();
@@ -1657,7 +1657,7 @@ bool KFileReplacePart::checkBeforeOperation()
return true;
}
-bool KFileReplacePart::dontAskAgain()
+bool TDEFileReplacePart::dontAskAgain()
{
m_config->setGroup("Notification Messages");
TQString dontAskAgain = m_config->readEntry(rcDontAskAgain, "no");
@@ -1667,7 +1667,7 @@ bool KFileReplacePart::dontAskAgain()
return false;
}
-void KFileReplacePart::whatsThis()
+void TDEFileReplacePart::whatsThis()
{
actionCollection()->action("options_backup")->setWhatsThis(optionsBackupWhatthis);
actionCollection()->action("options_case")->setWhatsThis(optionsCaseWhatthis);
diff --git a/tdefilereplace/tdefilereplacepart.desktop b/tdefilereplace/tdefilereplacepart.desktop
index de5ba1ee..baf3db8e 100644
--- a/tdefilereplace/tdefilereplacepart.desktop
+++ b/tdefilereplace/tdefilereplacepart.desktop
@@ -45,7 +45,7 @@ Comment[uk]=Засіб пакетного пошуку та заміни
Comment[zh_CN]=批量搜索替换工具
Comment[zh_HK]=批次搜尋及取代工具
Comment[zh_TW]=批次搜尋及取代工具
-Name=KFileReplace
+Name=TDEFileReplace
Name[hi]=के-फ़ाइल-रिप्लेस
Name[ne]=बदल्ने केडीई फाइल
Name[pa]=ਕੇ-ਫਾਇਲ-ਬਦਲੋ
@@ -59,7 +59,7 @@ GenericName[bg]=Преглед на файловете за замяна
GenericName[ca]=Vista per a substituir fitxers
GenericName[cs]=Nahrazení souborů
GenericName[da]=Filerstatningsvisning
-GenericName[de]=KFileReplace
+GenericName[de]=TDEFileReplace
GenericName[el]=Προβολή αντικατάστασης αρχείου
GenericName[es]=Vista de reemplazo de archivo
GenericName[et]=Failide asendamise vaade
diff --git a/tdefilereplace/tdefilereplacepart.h b/tdefilereplace/tdefilereplacepart.h
index 4ab3ab3b..0ca917e0 100644
--- a/tdefilereplace/tdefilereplacepart.h
+++ b/tdefilereplace/tdefilereplacepart.h
@@ -25,17 +25,17 @@ class TDEConfig;
// local
#include "configurationclasses.h"
-class KFileReplaceView;
+class TDEFileReplaceView;
#define KFR_VERSION "0.8.1"
-class KFileReplacePart: public KParts::ReadOnlyPart
+class TDEFileReplacePart: public KParts::ReadOnlyPart
{
Q_OBJECT
private: //MEMBERS
- KFileReplaceView* m_view;
+ TDEFileReplaceView* m_view;
TQWidget* m_parentWidget,
* m_w;
TDEConfig* m_config;
@@ -47,12 +47,12 @@ class KFileReplacePart: public KParts::ReadOnlyPart
int m_optionMask;
public://Constructors
- KFileReplacePart(TQWidget *parentWidget,
+ TDEFileReplacePart(TQWidget *parentWidget,
const char *widgetName,
TQObject *parent,
const char *name,
const TQStringList &args);
- ~KFileReplacePart();
+ ~TDEFileReplacePart();
//SLOTS
private slots:
@@ -157,4 +157,4 @@ class KFileReplacePart: public KParts::ReadOnlyPart
void whatsThis();
};
-#endif// KFileReplacePart
+#endif// TDEFileReplacePart
diff --git a/tdefilereplace/tdefilereplacepartui.rc b/tdefilereplace/tdefilereplacepartui.rc
index 797809c6..e9461446 100644
--- a/tdefilereplace/tdefilereplacepartui.rc
+++ b/tdefilereplace/tdefilereplacepartui.rc
@@ -52,7 +52,7 @@
</Menu>
</MenuBar>
<ToolBar noMerge="1" name="mainToolBar">
-<text>KFileReplace Main Toolbar</text>
+<text>TDEFileReplace Main Toolbar</text>
<Action name="new_project" />
<Action name="search"/>
<Action name="file_simulate"/>
diff --git a/tdefilereplace/tdefilereplaceview.h b/tdefilereplace/tdefilereplaceview.h
index bac91dcb..cf738964 100644
--- a/tdefilereplace/tdefilereplaceview.h
+++ b/tdefilereplace/tdefilereplaceview.h
@@ -54,7 +54,7 @@ class coord
/**
* The view of KFilereplace.
*/
-class KFileReplaceView : public KFileReplaceViewWdg
+class TDEFileReplaceView : public TDEFileReplaceViewWdg
{
Q_OBJECT
@@ -66,7 +66,7 @@ class KFileReplaceView : public KFileReplaceViewWdg
* m_sv;
public://Constructors
- KFileReplaceView(RCOptions* info, TQWidget *parent,const char *name);
+ TDEFileReplaceView(RCOptions* info, TQWidget *parent,const char *name);
public:
TQString currentPath();
diff --git a/tdefilereplace/tdefilereplaceviewwdg.ui b/tdefilereplace/tdefilereplaceviewwdg.ui
index e823993b..f7aaf87e 100644
--- a/tdefilereplace/tdefilereplaceviewwdg.ui
+++ b/tdefilereplace/tdefilereplaceviewwdg.ui
@@ -1,8 +1,8 @@
<!DOCTYPE UI><UI version="3.2" stdsetdef="1">
-<class>KFileReplaceViewWdg</class>
+<class>TDEFileReplaceViewWdg</class>
<widget class="TQWidget">
<property name="name">
- <cstring>KFileReplaceViewWdg</cstring>
+ <cstring>TDEFileReplaceViewWdg</cstring>
</property>
<property name="geometry">
<rect>
diff --git a/tdefilereplace/whatthis.h b/tdefilereplace/whatthis.h
index cf05cc00..05395373 100644
--- a/tdefilereplace/whatthis.h
+++ b/tdefilereplace/whatthis.h
@@ -25,7 +25,7 @@
namespace whatthisNameSpace
{
- //KFileReplaceView messages
+ //TDEFileReplaceView messages
const TQString lvResultWhatthis = i18n("Shows the statistics of your operations. Note that the columns content changes depending on what kind of operation you are performing.");
const TQString lvStringsWhatthis = i18n("Shows a list of strings to search for (and if you specified it, a list of strings to replace with). Use the \"add strings\" dialog to edit your string list or double click on a string.");
@@ -76,7 +76,7 @@ namespace whatthisNameSpace
const TQString chbConfirmStringsWhatthis = i18n("Enable this option if you want to be asked for single string replacement confirmation.");
- //KFileReplacePart
+ //TDEFileReplacePart
const TQString fileSimulateWhatthis = i18n("Enable this option to perform replacing as a simulation, i.e. without make any changes in files.");
const TQString optionsRegularExpressionsWhatthis = chbRegularExpressionsWhatthis;
diff --git a/tdefilereplace/tdefilereplacelib.cpp b/tdefilereplace/tdefilereplacelib.cpp
index 558b9dfb..3b73cd40 100644
--- a/tdefilereplace/tdefilereplacelib.cpp
+++ b/tdefilereplace/tdefilereplacelib.cpp
@@ -48,7 +48,7 @@ const double tera = 1099511627776.0;//1024^4
.................* fileName: second path (can be "/doc/html/", or "doc/html/" or "doc/html/index.html" for example)
Return values:...* Full valid path (without double "/")
*/
-TQString KFileReplaceLib::formatFullPath(const TQString& basePath, const TQString &fileName)
+TQString TDEFileReplaceLib::formatFullPath(const TQString& basePath, const TQString &fileName)
{
TQString fullPath = basePath;
TQString fname = fileName;
@@ -70,7 +70,7 @@ TQString KFileReplaceLib::formatFullPath(const TQString& basePath, const TQStrin
.................* extension: extension to add without "." (ex: "html", "kfr")
Return values:...* Filename / Filepath with the extension
*/
-TQString KFileReplaceLib::addExtension(const TQString& fileName, const TQString& extension)
+TQString TDEFileReplaceLib::addExtension(const TQString& fileName, const TQString& extension)
{
TQString fullExtension = ".";
TQString fname = fileName;
@@ -89,7 +89,7 @@ TQString KFileReplaceLib::addExtension(const TQString& fileName, const TQString&
return fname;
}
-TQString KFileReplaceLib::formatFileSize(double size)
+TQString TDEFileReplaceLib::formatFileSize(double size)
{
TQString stringSize;
@@ -119,12 +119,12 @@ TQString KFileReplaceLib::formatFileSize(double size)
return stringSize;
}
-void KFileReplaceLib::convertOldToNewKFRFormat(const TQString& fileName, TDEListView* stringView)
+void TDEFileReplaceLib::convertOldToNewKFRFormat(const TQString& fileName, TDEListView* stringView)
{
//this method convert old format in new XML-based format
typedef struct
{
- char pgm[13]; // Must be "KFileReplace" : like MZ for EXE files
+ char pgm[13]; // Must be "TDEFileReplace" : like MZ for EXE files
int stringNumber; // Number of strings in file
char reserved[64]; // Reserved for future use
} KFRHeader;
@@ -135,7 +135,7 @@ void KFileReplaceLib::convertOldToNewKFRFormat(const TQString& fileName, TDEList
int err = fread(&head, sizeof(KFRHeader), 1, f);
TQString pgm(head.pgm);
- if(!f || (err != 1) || (pgm != "KFileReplace"))
+ if(!f || (err != 1) || (pgm != "TDEFileReplace"))
{
KMessageBox::error(0, i18n("<qt>Cannot open the file <b>%1</b> and load the string list. This file seems not to be a valid old kfr file or it is broken.</qt>").arg(fileName));
return ;
@@ -195,7 +195,7 @@ void KFileReplaceLib::convertOldToNewKFRFormat(const TQString& fileName, TDEList
return ;
}
-bool KFileReplaceLib::isAnAccessibleFile(const TQString& filePath, const TQString& fileName, RCOptions* info)
+bool TDEFileReplaceLib::isAnAccessibleFile(const TQString& filePath, const TQString& fileName, RCOptions* info)
{
TQString bkExt = info->m_backupExtension;
if(fileName == ".." || fileName == "." || (!bkExt.isEmpty() && fileName.right(bkExt.length()) == bkExt))
@@ -296,7 +296,7 @@ bool KFileReplaceLib::isAnAccessibleFile(const TQString& filePath, const TQStrin
return true;
}
-void KFileReplaceLib::setIconForFileEntry(TQListViewItem* item, TQString path)
+void TDEFileReplaceLib::setIconForFileEntry(TQListViewItem* item, TQString path)
{
TQFileInfo fi(path);
TQString extension = fi.extension(),
diff --git a/tdefilereplace/tdefilereplaceview.cpp b/tdefilereplace/tdefilereplaceview.cpp
index 1d60f3d5..44aad1fd 100644
--- a/tdefilereplace/tdefilereplaceview.cpp
+++ b/tdefilereplace/tdefilereplaceview.cpp
@@ -43,7 +43,7 @@
using namespace whatthisNameSpace;
-KFileReplaceView::KFileReplaceView(RCOptions* info, TQWidget *parent,const char *name):KFileReplaceViewWdg(parent,name)
+TDEFileReplaceView::TDEFileReplaceView(RCOptions* info, TQWidget *parent,const char *name):TDEFileReplaceViewWdg(parent,name)
{
m_option = info;
@@ -58,7 +58,7 @@ KFileReplaceView::KFileReplaceView(RCOptions* info, TQWidget *parent,const char
whatsThis();
}
-TQString KFileReplaceView::currentPath()
+TQString TDEFileReplaceView::currentPath()
{
TQListViewItem *lvi;
@@ -71,7 +71,7 @@ TQString KFileReplaceView::currentPath()
return TQString(lvi->text(1)+"/"+lvi->text(0));
}
-void KFileReplaceView::showSemaphore(TQString s)
+void TDEFileReplaceView::showSemaphore(TQString s)
{
if(s == "green")
{
@@ -95,7 +95,7 @@ void KFileReplaceView::showSemaphore(TQString s)
}
}
-void KFileReplaceView::stringsInvert(bool invertAll)
+void TDEFileReplaceView::stringsInvert(bool invertAll)
{
TQListViewItem* lviCurItem,
* lviFirst;
@@ -131,7 +131,7 @@ void KFileReplaceView::stringsInvert(bool invertAll)
setCurrentStringsViewMap();
}
-void KFileReplaceView::changeView(bool searchingOnlyMode)
+void TDEFileReplaceView::changeView(bool searchingOnlyMode)
{
if(searchingOnlyMode)
{
@@ -149,7 +149,7 @@ void KFileReplaceView::changeView(bool searchingOnlyMode)
}
}
-TDEListView* KFileReplaceView::getResultsView()
+TDEListView* TDEFileReplaceView::getResultsView()
{
if(m_option->m_searchingOnlyMode)
m_rv = m_lvResults_2;
@@ -159,7 +159,7 @@ TDEListView* KFileReplaceView::getResultsView()
return m_rv;
}
-TDEListView* KFileReplaceView::getStringsView()
+TDEListView* TDEFileReplaceView::getStringsView()
{
if(m_option->m_searchingOnlyMode)
m_sv = m_lvStrings_2;
@@ -169,7 +169,7 @@ TDEListView* KFileReplaceView::getStringsView()
}
//PUBLIC SLOTS
-void KFileReplaceView::slotMouseButtonClicked (int button, TQListViewItem *lvi, const TQPoint &pos)
+void TDEFileReplaceView::slotMouseButtonClicked (int button, TQListViewItem *lvi, const TQPoint &pos)
{
if (lvi == 0) // No item selected
return;
@@ -182,7 +182,7 @@ void KFileReplaceView::slotMouseButtonClicked (int button, TQListViewItem *lvi,
}
}
-void KFileReplaceView::slotResultProperties()
+void TDEFileReplaceView::slotResultProperties()
{
TQString currItem = currentPath();
if(! currItem.isEmpty())
@@ -193,7 +193,7 @@ void KFileReplaceView::slotResultProperties()
}
}
-void KFileReplaceView::slotResultOpen()
+void TDEFileReplaceView::slotResultOpen()
{
TQString currItem = currentPath();
if(!currItem.isEmpty())
@@ -203,7 +203,7 @@ void KFileReplaceView::slotResultOpen()
}
}
-void KFileReplaceView::slotResultOpenWith()
+void TDEFileReplaceView::slotResultOpenWith()
{
TQString currItem = currentPath();
if(!currItem.isEmpty())
@@ -215,7 +215,7 @@ void KFileReplaceView::slotResultOpenWith()
}
}
-void KFileReplaceView::slotResultDirOpen()
+void TDEFileReplaceView::slotResultDirOpen()
{
TQString currItem = currentPath();
if(!currItem.isEmpty())
@@ -227,7 +227,7 @@ void KFileReplaceView::slotResultDirOpen()
}
}
-void KFileReplaceView::slotResultEdit()
+void TDEFileReplaceView::slotResultEdit()
{
TQListViewItem *lvi = m_rv->firstChild();
@@ -272,7 +272,7 @@ void KFileReplaceView::slotResultEdit()
m_lviCurrent = 0;
}
-void KFileReplaceView::slotResultDelete()
+void TDEFileReplaceView::slotResultDelete()
{
TQString currItem = currentPath();
if (!currItem.isEmpty())
@@ -292,7 +292,7 @@ void KFileReplaceView::slotResultDelete()
}
}
-void KFileReplaceView::slotResultTreeExpand()
+void TDEFileReplaceView::slotResultTreeExpand()
{
TQListViewItem *lviRoot = getResultsView()->firstChild();
@@ -300,7 +300,7 @@ void KFileReplaceView::slotResultTreeExpand()
expand(lviRoot, true);
}
-void KFileReplaceView::slotResultTreeReduce()
+void TDEFileReplaceView::slotResultTreeReduce()
{
TQListViewItem *lviRoot = getResultsView()->firstChild();
@@ -308,7 +308,7 @@ void KFileReplaceView::slotResultTreeReduce()
expand(lviRoot, false);
}
-void KFileReplaceView::slotStringsAdd()
+void TDEFileReplaceView::slotStringsAdd()
{
KeyValueMap oldMap(m_option->m_mapStringsView);
@@ -331,7 +331,7 @@ void KFileReplaceView::slotStringsAdd()
loadMapIntoView(addedStringsMap);
}
-void KFileReplaceView::slotQuickStringsAdd(const TQString& quickSearch, const TQString& quickReplace)
+void TDEFileReplaceView::slotQuickStringsAdd(const TQString& quickSearch, const TQString& quickReplace)
{
if(!quickSearch.isEmpty())
{
@@ -356,7 +356,7 @@ void KFileReplaceView::slotQuickStringsAdd(const TQString& quickSearch, const TQ
}
}
-void KFileReplaceView::slotStringsEdit()
+void TDEFileReplaceView::slotStringsEdit()
{
KeyValueMap oldMap(m_option->m_mapStringsView);
if(oldMap.isEmpty()) return;
@@ -391,7 +391,7 @@ void KFileReplaceView::slotStringsEdit()
loadMapIntoView(newMap);
}
-void KFileReplaceView::slotStringsSave()
+void TDEFileReplaceView::slotStringsSave()
{
// Check there are strings in the list
TDEListView* sv = getStringsView();
@@ -422,14 +422,14 @@ void KFileReplaceView::slotStringsSave()
}
// Selects the file where strings will be saved
- TQString menu = "*.kfr|" + i18n("KFileReplace Strings") + " (*.kfr)\n*|" + i18n("All Files") + " (*)";
+ TQString menu = "*.kfr|" + i18n("TDEFileReplace Strings") + " (*.kfr)\n*|" + i18n("All Files") + " (*)";
TQString fileName = KFileDialog::getSaveFileName(TQString(), menu, 0, i18n("Save Strings to File"));
if (fileName.isEmpty())
return;
- // Forces the extension to be "kfr" == KFileReplace extension
+ // Forces the extension to be "kfr" == TDEFileReplace extension
- fileName = KFileReplaceLib::addExtension(fileName, "kfr");
+ fileName = TDEFileReplaceLib::addExtension(fileName, "kfr");
TQFile file( fileName );
if(!file.open( IO_WriteOnly ))
@@ -445,7 +445,7 @@ void KFileReplaceView::slotStringsSave()
file.close();
}
-void KFileReplaceView::slotStringsDeleteItem()
+void TDEFileReplaceView::slotStringsDeleteItem()
{
TQListViewItem* item = m_sv->currentItem();
if(item != 0)
@@ -457,7 +457,7 @@ void KFileReplaceView::slotStringsDeleteItem()
}
}
-void KFileReplaceView::slotStringsEmpty()
+void TDEFileReplaceView::slotStringsEmpty()
{
TQListViewItem * myChild = m_sv->firstChild();
while( myChild )
@@ -471,7 +471,7 @@ void KFileReplaceView::slotStringsEmpty()
}
//PRIVATE
-void KFileReplaceView::initGUI()
+void TDEFileReplaceView::initGUI()
{
m_option->m_searchingOnlyMode = true;
@@ -534,7 +534,7 @@ void KFileReplaceView::initGUI()
raiseStringsView();
}
-void KFileReplaceView::raiseStringsView()
+void TDEFileReplaceView::raiseStringsView()
{
if(m_option->m_searchingOnlyMode)
m_sv = m_lvStrings_2;
@@ -544,7 +544,7 @@ void KFileReplaceView::raiseStringsView()
m_stackStrings->raiseWidget(m_sv);
}
-void KFileReplaceView::raiseResultsView()
+void TDEFileReplaceView::raiseResultsView()
{
if(m_option->m_searchingOnlyMode)
m_rv = m_lvResults_2;
@@ -554,7 +554,7 @@ void KFileReplaceView::raiseResultsView()
m_stackResults->raiseWidget(m_rv);
}
-coord KFileReplaceView::extractWordCoordinates(TQListViewItem* lvi)
+coord TDEFileReplaceView::extractWordCoordinates(TQListViewItem* lvi)
{
//get coordinates of the first string of the current selected file
coord c;
@@ -618,7 +618,7 @@ coord KFileReplaceView::extractWordCoordinates(TQListViewItem* lvi)
return c;
}
-void KFileReplaceView::expand(TQListViewItem *lviCurrent, bool b)
+void TDEFileReplaceView::expand(TQListViewItem *lviCurrent, bool b)
{
// current item
lviCurrent->setOpen(b);
@@ -633,7 +633,7 @@ void KFileReplaceView::expand(TQListViewItem *lviCurrent, bool b)
}
}
-void KFileReplaceView::setMap()
+void TDEFileReplaceView::setMap()
{
KeyValueMap map;
TQListViewItem* i = m_sv->firstChild();
@@ -648,7 +648,7 @@ void KFileReplaceView::setMap()
m_option->m_mapStringsView = map;
}
-void KFileReplaceView::loadMapIntoView(KeyValueMap map)
+void TDEFileReplaceView::loadMapIntoView(KeyValueMap map)
{
m_sv->clear();
KeyValueMap::Iterator itMap;
@@ -664,7 +664,7 @@ void KFileReplaceView::loadMapIntoView(KeyValueMap map)
}
-void KFileReplaceView::whatsThis()
+void TDEFileReplaceView::whatsThis()
{
TQWhatsThis::add(getResultsView(), lvResultWhatthis);
TQWhatsThis::add(getStringsView(), lvStringsWhatthis);